@@ -2,6 +2,9 @@ require 'grape_logging/multi_io'
 require 'grape_logging/version'
 require 'grape_logging/formatters/default'
 require 'grape_logging/formatters/json'
+require 'grape_logging/formatters/lograge'
+require 'grape_logging/formatters/logstash'
+require 'grape_logging/formatters/rails'
 require 'grape_logging/loggers/base'
 require 'grape_logging/loggers/response'
 require 'grape_logging/loggers/filter_parameters'
@@ -11,3 +14,4 @@ require 'grape_logging/reporters/active_support_reporter'
 require 'grape_logging/reporters/logger_reporter'
 require 'grape_logging/timings'
 require 'grape_logging/middleware/request_logger'
+require 'grape_logging/util/parameter_filter'
